.. _api_reference:

****************
API reference
****************

Documentation of the different classes, starting from the app layer down to the model layer.

App
=======

.. automodule:: insightvault.app.base
    :members:

.. automodule:: insightvault.app.cli
    :members:

.. automodule:: insightvault.app.rag
    :members:

.. automodule:: insightvault.app.search
    :members:

.. automodule:: insightvault.app.summarizer
    :members:

Services
============

.. automodule:: insightvault.services.database
    :members:

.. automodule:: insightvault.services.embedding
    :members:

.. automodule:: insightvault.services.llm
    :members:

.. automodule:: insightvault.services.prompt
    :members:

.. automodule:: insightvault.services.splitter
    :members:


Models
============

.. automodule:: insightvault.models.database
    :members:

.. automodule:: insightvault.models.document
    :members:
